AuthResult class

The result when the Twitter login flow has completed. The login methods always return an instance of this class.

Constructors

AuthResult({String? authToken, String? authTokenSecret, required TwitterLoginStatus status, String? errorMessage, User? user})
constructor

Properties

authToken → String?
no setter
authTokenSecret → String?
no setter
errorMessage → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TwitterLoginStatus?
no setter
user → User?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited