AccessToken class

The access token for Twitter API.

Constructors

AccessToken(Map<String, dynamic> params)

Properties

authToken → String?
final
authTokenSecret → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenName → String?
final
userId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getAccessToken(String apiKey, String apiSecretKey, Map<String, String> queries) → Future<AccessToken>