RequestToken class

The Request token for Twitter API.

Constructors

RequestToken(Map<String, dynamic> params, String authorizeURI)
constructor

Properties

authorizeURI → String
authorize url
no setter
callbackConfirmed → String
Oauth callback confirmed
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
Oauth token
no setter
tokenSecret → String
Oauth token secret
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getRequestToken(String apiKey, String apiSecretKey, String redirectURI, bool forceLogin) → Future<RequestToken>
Request user authorization token